OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, selecione um ficheiro.",
    "File is too big" : "O ficheiro é demasiado grande",
    "The selected file is not an image." : "O ficheiro selecionado não é uma imagem.",
    "The selected file cannot be read." : "O ficheiro selecionado não pode ser lido.",
    "The file was uploaded" : "O ficheiro foi carregado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O tamanho do ficheiro enviado excede a diretiva MAX_FILE_SIZE definida no formulário HTML",
    "The file was only partially uploaded" : "O ficheiro foi apenas parcialmente carregado",
    "No file was uploaded" : "Não foi carregado nenhum ficheiro",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever o ficheiro no disco.",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o carregamento do ficheiro.",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "No image or file provided" : "Imagem ou ficheiro não fornecido",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Por favor, contacte o seu administrador.",
    "Invalid image" : "Imagem inválida",
    "No temporary profile picture available, try again" : "Nenhuma imagem de perfil temporária disponível, tente novamente",
    "No crop data provided" : "Não foram fornecidos dados de recorte",
    "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
    "Crop is not square" : "O recorte não é quadrado",
    "State token does not match" : "O token de estado não corresponde",
    "Invalid app password" : "Palavra-passe de aplicação inválida",
    "Could not complete login" : "Não foi possível fazer login",
    "Your login token is invalid or has expired" : "O seu token de login é inválido ou expirou",
    "Login" : "Iniciar sessão",
    "Password reset is disabled" : "A reposição da senha está desativada",
    "Could not reset password because the token is expired" : "Não foi possível redefinir a palavra-passe porque o token expirou",
    "Could not reset password because the token is invalid" : "Não foi possível redefinir a palavra-passe porque o token é inválido",
    "%s password reset" : "%s reposição de palavra-passe",
    "Password reset" : "Reposição da senha",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no seguinte botão para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique na seguinte hiperligação para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
    "Reset your password" : "Repor a senha",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Alguns dos links das suas partilhas foram removidos",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a bugs de segurança tivemos que remover algumas das suas ligações às partilhas.\nPor favor veja o link para mais informação.",
    "The user limit of this instance is reached." : "O limite de utilizador desta instância foi atingido",
    "Learn more ↗" : "Aprenda mais ↗",
    "Preparing update" : "A preparar a atualização",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Etapa da reparação:",
    "Repair info:" : "Informação da reparação:",
    "Repair warning:" : "Aviso de reparação:",
    "Repair error:" : "Erro de reparação:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, utilize o atualizador da linha de comandos porque a atualização automática está desativada no config.php.",
    "Turned on maintenance mode" : "Ativou o modo de manutenção",
    "Turned off maintenance mode" : "Desativou o modo de manutenção",
    "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
    "Updating database schema" : "A atualizar o esquema da base de dados",
    "Updated database" : "Base de dados atualizada",
    "Update app \"%s\" from App Store" : "Actualizar a aplicação \"%s\" da Loja de Aplicações",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo, dependendo do tamanho da base de dados)",
    "Updated \"%1$s\" to %2$s" : "Atualizar \"%1$s\" para %2$s",
    "Set log level to debug" : "Definir nível de registo para depurar",
    "Reset log level" : "Reiniciar nível de registo",
    "Starting code integrity check" : "A iniciar a verificação da integridade do código",
    "Finished code integrity check" : "Terminada a verificação da integridade do código",
    "%s (incompatible)" : "%s (incompatível)",
    "The following apps have been disabled: %s" : "As seguintes aplicações foram desactivadas: %s",
    "Already up to date" : "Já está atualizado",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "O seu webserver não está configurado correctamente resolver \"{url}\". Pode encontrar mais informações na documentação {linkstart} ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "O seu servidor web não está configurado correctamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor web que não foi actualizada para entregar essa pasta directamente. Compare a sua configuração com as regras de reescrita disponibilizadas em \".htaccess\" para Apache ou as fornecida na documentação para Nginx na {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma actualização. ",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "O seu servidor web não está configurado correctamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada na nossa {linkstart}documentação ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, verifique a {linkstart}documentação de instalação ↗{linkend} para notas de configuração de PHP e a configuração de PHP do seu servidor, especialmente ao utilizar php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "O módulo PHP 'fileinfo' está ausente. Recomendamos vivamente que ative este módulo para obter melhores resultados na detecção de tipo MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "O bloqueio de arquivo transaccional está desativado, isso pode levar a problemas com condições de corrida. Ative \"filelocking.enabled\" em config.php para evitar esses problemas. Consulte a {linkstart}documentação ↗{linkend} para obter mais informação.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "A instalação não tem uma região de telefone predefinida. A região predefinida é necessária para validar números de telefone sem código de país nas configurações do perfil . Para permitir números sem um código de país, adicione \"default_phone_region\" com o respectivo {linkstart}código ISO 3166-1 ↗{linkend} da região ao seu ficheiro de configuração.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron job via CLI. Ocorreram os seguintes erros técnicos:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A última execução do trabalho em segundo plano foi {relativeTime}. Parece que há algo errado. {linkstart}Verifique as configurações do trabalho em segundo plano ↗{linkend}.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Índice \"{indexName}\" em falta na tabela \"{tableName}\".",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Esta instância tem em falta alguns módulos PHP recomendados. Para melhor desempenho e melhor compatibilidade, é altamente recomendável instalá-los.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite é atualmente utilizado como a base de dados de backend. Para instalações maiores recomendamos que mude para uma base de dados de backend diferente.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Isto é particularmente recomendado quando estiver a usar um cliente de desktop para sincronização de ficheiros.",
    "The PHP memory limit is below the recommended value of 512MB." : "O limite de memória do PHP está abaixo do valor recomendado de 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Algumas diretorias de aplicações pertencem a um utilizador diferente do servidor web. Pode ser esse o caso se as aplicações foram instaladas manualmente. Verifique as permissões das seguintes diretorias de aplicações:",
    "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
    "unknown text" : "texto desconhecido",
    "Hello world!" : "Olá, mundo!",
    "sunny" : "soalheiro",
    "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
    "Hello {name}" : "Olá {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualização está a decorrer. Se deixar esta página o processo pode ser interrompido.",
    "Update to {version}" : "Actualizar para {version}",
    "An error occurred." : "Ocorreu um erro.",
    "Please reload the page." : "Por favor, recarregue a página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">consulte o nosso artigo do fórum</a> sobre como resolver este problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, informe este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
    "Continue to {productName}" : "Continuar para {productName}",
    "More apps" : "Mais apps",
    "Log in" : "Iniciar sessão",
    "Logging in …" : "A entrar...",
    "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
    "Please contact your administrator." : "Por favor, contacte o seu administrador.",
    "An internal error occurred." : "Ocorreu um erro interno.",
    "Please try again or contact your administrator." : "Por favor, tente novamente ou contacte o seu administrador.",
    "Password" : "Palavra-passe",
    "Wrong username or password." : "Nome de utilizador ou palavra passe errados",
    "User disabled" : "Utilizador desativado",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
    "Username or email" : "Utilizador ou e-mail",
    "Your account is not setup for passwordless login." : "A sua conta não está configurada para autenticação sem palavra-passe.",
    "Browser not supported" : "Navegador não suportado",
    "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
    "Your connection is not secure" : "A sua ligação não é segura",
    "Passwordless authentication is only available over a secure connection." : "A autenticação sem palavra-passe só está disponível através de uma ligação segura.",
    "Reset password" : "Repor palavra-passe",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Foi enviada uma mensagem de reposição da sua palavra-passe para o endereço de email desta conta. Se não a receber, verifique as pastas de spam/lixo ou entre em contacto com o administrador local para ajuda.",
    "If it is not there ask your local administrator." : "Se não estiver aí pergunte ao seu administrador local.",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
    "Password cannot be changed. Please contact your administrator." : "A senha não pode ser alterada. Contacte o seu administrador.",
    "Back to login" : "Voltar à entrada",
    "New password" : "Nova palavra-passe",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Os seus ficheiros estão cifrados. Não será possível aceder aos seus dados após a palavra-passe ser alterada. Se não tiver a certeza do que fazer, contacte o administrador do sistema antes de continuar. Tem a certeza que quer continuar?",
    "I know what I'm doing" : "Eu sei o que eu estou a fazer",
    "Resetting password" : "A fazer reset à palavra passe",
    "Recommended apps" : "Aplicações recomendadas",
    "Loading apps …" : "A carregar aplicações...",
    "Installing apps …" : "A instalar aplicações ...",
    "App download or installation failed" : "A transferência ou a instalação desta aplicação falhou",
    "Cannot install this app because it is not compatible" : "Não é possível instalar esta aplicação por não ser compatível",
    "Cannot install this app" : "Não é possível instalar esta aplicação",
    "Skip" : "Saltar",
    "Install recommended apps" : "Instalar aplicações recomendadas",
    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
    "Forgot password?" : "Senha esquecida?",
    "Back" : "Anterior",
    "Edit Profile" : "Editar perfil",
    "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
    "Reset search" : "Redefinir pesquisa",
    "Search for {name} only" : "Pesquisar apenas por {name}",
    "No results for {query}" : "Nenhum resultado para {query}",
    "Start typing to search" : "Digitar para pesquisar",
    "Loading more results …" : "A carregar mais resultados...",
    "Load more results" : "Mostrar mais resultados...",
    "Search" : "Procurar",
    "Search {types} …" : "Pesquisar {types}...",
    "Settings" : "Definições",
    "Could not load your contacts" : "Não foi possível carregar os seus contactos",
    "Search contacts …" : "Pesquisar contactos...",
    "No contacts found" : "Não foram encontrados contactos",
    "Show all contacts …" : "Mostrar todos os contactos ...",
    "Install the Contacts app" : "Instalar a app Contactos",
    "Loading your contacts …" : "A carregar os seus contactos",
    "Looking for {term} …" : "Procurando por {term} …",
    "No" : "Não",
    "Yes" : "Sim",
    "No files in here" : "Sem ficheiros aqui",
    "New folder" : "Nova pasta",
    "No more subfolders in here" : "Atualmente não existem subpastas aqui",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
    "{newName} already exists" : "{newName} já existe",
    "Choose" : "Escolher",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Ocorreu um erro ao carregar o modelo de seleção de ficheiro: {error}",
    "OK" : "Confirmar",
    "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
    "read-only" : "só de leitura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro","{count} conflitos de ficheiro"],
    "One file conflict" : "Um conflito de ficheiro",
    "New Files" : "Novos Ficheiros",
    "Already existing files" : "Ficheiros já existentes",
    "Which files do you want to keep?" : "Quais os ficheiros que pretende manter?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selecionar ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos selecionados)",
    "({count} selected)" : "({count} selecionados)",
    "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
    "Pending" : "Pendente",
    "Copy to {folder}" : "Copiar para {folder}",
    "Move to {folder}" : "Mover para {folder}",
    "Saving …" : "A guardar...",
    "Authentication required" : "Autenticação necessária",
    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Falha ao autenticar. Tente outra vez.",
    "seconds ago" : "segundos atrás",
    "Connection to server lost" : "Ligação perdida ao servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos"],
    "Add to a project" : "Adicionar a um projeto",
    "Show details" : "Mostrar detalhes",
    "Hide details" : "Ocultar detalhes",
    "Rename project" : "Renomear projeto",
    "Failed to rename the project" : "Erro ao renomear o projeto",
    "Failed to create a project" : "Erro ao criar o projeto",
    "Failed to add the item to the project" : "Falha ao adicionar item ao projeto",
    "Connect items to a project to make them easier to find" : "Ligar itens a um projeto para poderem ser mais facilmente encontrados",
    "Type to search for existing projects" : "Digite para procurar por projetos existentes",
    "New in" : "Novo em",
    "View changelog" : "Ver Registo de alterações",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "No action available" : "Nenhuma acção disponível",
    "Error fetching contact actions" : "Erro ao obter acções dos contactos",
    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
    "Invisible" : "Invisível ",
    "Delete" : "Eliminar",
    "Rename" : "Renomear",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "Etiquetas não encontradas",
    "Personal" : "Pessoal",
    "Users" : "Utilizadores",
    "Apps" : "Aplicações",
    "Admin" : "Administração",
    "Help" : "Ajuda",
    "Access forbidden" : "Acesso proibido",
    "Profile not found" : "Perfil não encontrado",
    "The profile does not exist." : "O perfil não existe.",
    "Back to %s" : "Voltar a %s",
    "Page not found" : "Página não encontrada",
    "Too many requests" : "Muitos pedidos",
    "Error" : "Erro",
    "Previous" : "Anterior",
    "Internal Server Error" : "Erro Interno do Servidor",
    "The server was unable to complete your request." : "O servidor não conseguiu completar o seu pedido.",
    "If this happens again, please send the technical details below to the server administrator." : "Se voltar a  acontecer, por favor envie os detalhes técnicos abaixo ao administrador do servidor.",
    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "ID do pedido: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensagem: %s",
    "File: %s" : "Ficheiro: %s",
    "Line: %s" : "Linha: %s",
    "Trace" : "Rastreio",
    "Security warning" : "Aviso de Segurança",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
    "Create an <strong>admin account</strong>" : "Criar uma <strong>conta administrativa</strong>",
    "Username" : "Nome de utilizador",
    "Show password" : "Mostrar senha",
    "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
    "Storage & database" : "Armazenamento e base de dados",
    "Data folder" : "Pasta de dados",
    "Configure the database" : "Configure a base de dados",
    "Only %s is available." : "Só está disponível %s.",
    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
    "Database user" : "Utilizador da base de dados",
    "Database password" : "Palavra-passe da base de dados",
    "Database name" : "Nome da base de dados",
    "Database tablespace" : "Tablespace da base de dados",
    "Database host" : "Anfitrião da base de dados",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
    "Performance warning" : "Aviso de desempenho",
    "You chose SQLite as database." : "Escolheu SQLite como base de dados",
    "Install" : "Instalar",
    "Installing …" : "A instalar...",
    "Need help?" : "Precisa de ajuda?",
    "See the documentation" : "Consulte a documentação",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
    "Skip to main content" : "Saltar para conteúdo principal",
    "Skip to navigation of app" : "Saltar para navegação da aplicação",
    "Get your own free account" : "Obtenha a sua própria conta grátis",
    "Contacts" : "Contactos",
    "Contacts menu" : "Menu de contactos",
    "Confirm your password" : "Confirmar senha",
    "Connect to your account" : "Ligar à sua conta",
    "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
    "App token" : "Token da aplicação",
    "Grant access" : "Conceder acesso",
    "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
    "Account access" : "Acesso à conta",
    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir a %1$s aceder à sua conta conta %2$s. ",
    "Account connected" : "Conta ligada",
    "You can close this window." : "Pode fechar esta janela.",
    "This share is password-protected" : "Esta partilha está protegida por senha",
    "Email address" : "Endereço de email",
    "Go to %s" : "Ir para %s",
    "Two-factor authentication" : "Autenticação de dois fatores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança reforçada foi ativada para a sua conta. Por favor, escolha um segundo fator de autenticação.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar pelo menos um dos métodos de autenticação de dois passos activados. Por favor, contacte o seu administrador.",
    "Set up two-factor authentication" : "Configurar autenticação de dois fatores",
    "Use backup code" : "Usar código de cópia de segurança",
    "Cancel login" : "Cancelar login",
    "Error while validating your second factor" : "Erro ao validar o segundo fator",
    "Access through untrusted domain" : "Aceder através de um domínio não confiável",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador, edite a definição \"trusted_domains\" no config/config.php como no exemplo em config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informação acerca de como configurar pode ser encontrada na %1$sdocumentação%2$s. ",
    "App update required" : "É necessário atualizar a aplicação",
    "%1$s will be updated to version %2$s" : "%1$s irá ser atualizada para a versão %2$s",
    "These incompatible apps will be disabled:" : "Estas aplicações incompatíveis irão ser desativadas:",
    "The theme %s has been disabled." : "O tema %s foi desativado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
    "Start update" : "Iniciar atualização",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
    "Detailed logs" : "Registos detalhados",
    "Update needed" : "É necessário atualizar",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor, use o atualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar a fazer a atualização via interface web arrisco a que o pedido expire e pode causar a perda de dados, no entanto tenho uma cópia de segurança e sei como restaurar a minha instância em caso de falha. ",
    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco.",
    "Maintenance mode" : "Modo de manutenção",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
    "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduza a sua chave de subscrição para aumentar o limite de utilizadores. Para mais informações sobre A Nextcloud Enterprise consulte o website.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: a verificar a tabela %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor não tem ligação à Internet: Não foi possível detetar vários endpoints. Isso significa que algumas das funcionalidades como a montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicações de terceiros não funcionarão. Pode também não ser possível aceder a ficheiros remotamente e enviar e-mails de notificação. Sugerimos que ative a ligação à Internet para este servidor, caso pretenda ter todas as funcionalidades.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Os directórios de datos e ficheiros estão provavelmente acessíveis através da Internet. O ficheiro .htaccess não está a funcionar. É altamente recomendado que configure o seu servidor web para que o directório de dados deixa de estar acessível, ou movê-lo para fora da raiz de documentos do servidor web. ",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que se recomenda que ajuste esta opção em conformidade.",
    "restricted" : "limitado",
    "invisible" : "invisível",
    "File not found" : "Ficheiro não encontrado",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Este documento não pode ser encontrado no servidor. Talvez a partilha tenha sido apagada ou expirado?",
    "More" : "Mais",
    "More apps menu" : "Menu de mais aplicações",
    "Settings menu" : "Menu de configurações",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Setup two-factor authentication" : "Configurar autenticação de dois fatores",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Este é a construção de uma comunidade sem suporte do Nextcloud. Dado o tamanho desta instância, desempenho, confiabilidade e escalabilidade não podem ser garantidos. As notificações push foram desativadas para evitar sobrecarregar o nosso serviço gratuito. Saiba mais sobre os benefícios do Nextcloud Enterprise em nextcloud.com/enterprise. "
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
